package sun.awt.image;

import java.awt.image.WritableRaster;
import java.awt.image.ColorModel;
import java.awt.image.DirectColorModel;
import java.awt.image.IndexColorModel;
import java.awt.image.ImageConsumer;
import java.util.Hashtable;
import java.awt.image.BufferedImage;
import java.awt.image.ImageProducer;

public class OffScreenImageSource implements ImageProducer
{
    BufferedImage image;
    int width;
    int height;
    Hashtable properties;
    private ImageConsumer theConsumer;
    
    public OffScreenImageSource(BufferedImage image, Hashtable properties) {
        this.image = image;
        if (properties != null) {
            this.properties = properties;
        }
        else {
            this.properties = new Hashtable();
        }
        this.width = image.getWidth();
        this.height = image.getHeight();
    }
    
    public OffScreenImageSource(BufferedImage bufferedImage) {
        this(bufferedImage, null);
    }
    
    @Override
    public synchronized void addConsumer(ImageConsumer theConsumer) {
        this.theConsumer = theConsumer;
        this.produce();
    }
    
    @Override
    public synchronized boolean isConsumer(ImageConsumer imageConsumer) {
        return imageConsumer == this.theConsumer;
    }
    
    @Override
    public synchronized void removeConsumer(ImageConsumer imageConsumer) {
        if (this.theConsumer == imageConsumer) {
            this.theConsumer = null;
        }
    }
    
    @Override
    public void startProduction(ImageConsumer imageConsumer) {
        this.addConsumer(imageConsumer);
    }
    
    @Override
    public void requestTopDownLeftRightResend(ImageConsumer imageConsumer) {
    }
    
    private void sendPixels() {
        ColorModel colorModel = this.image.getColorModel();
        WritableRaster raster = this.image.getRaster();
        int numDataElements = raster.getNumDataElements();
        int dataType = raster.getDataBuffer().getDataType();
        int[] iArray = new int[this.width * numDataElements];
        boolean n = true;
        if ((colorModel instanceof IndexColorModel)) {
            byte[] outData3 = new byte[this.width];
            this.theConsumer.setColorModel(colorModel);
            if ((raster instanceof ByteComponentRaster)) {
                n = false;
                for (int y3 = 0; y3 < this.height; ++y3) {
                    raster.getDataElements(0, y3, this.width, 1, outData3);
                    this.theConsumer.setPixels(0, y3, this.width, 1, colorModel, outData3, 0, this.width);
                }
            }
            else if ((raster instanceof BytePackedRaster)) {
                n = false;
                for (int y2 = 0; y2 < this.height; ++y2) {
                    raster.getPixels(0, y2, this.width, 1, iArray);
                    for (int n3 = 0; n3 < this.width; ++n3) {
                        outData3[n3] = (byte)iArray[n3];
                    }
                    this.theConsumer.setPixels(0, y2, this.width, 1, colorModel, outData3, 0, this.width);
                }
            }
            else if (dataType == 2 || dataType == 3) {
                n = false;
                for (int y = 0; y < this.height; ++y) {
                    raster.getPixels(0, y, this.width, 1, iArray);
                    this.theConsumer.setPixels(0, y, this.width, 1, colorModel, iArray, 0, this.width);
                }
            }
        }
        else if ((colorModel instanceof DirectColorModel)) {
            this.theConsumer.setColorModel(colorModel);
            n = false;
            switch (dataType) {
                case 3: {
                    for (int i = 0; i < this.height; ++i) {
                        raster.getDataElements(0, i, this.width, 1, iArray);
                        this.theConsumer.setPixels(0, i, this.width, 1, colorModel, iArray, 0, this.width);
                    }
                    break;
                }
                case 0: {
                    byte[] outData = new byte[this.width];
                    for (int j = 0; j < this.height; ++j) {
                        raster.getDataElements(0, j, this.width, 1, outData);
                        for (int k = 0; k < this.width; ++k) {
                            iArray[k] = (outData[k] & 0xFF);
                        }
                        this.theConsumer.setPixels(0, j, this.width, 1, colorModel, iArray, 0, this.width);
                    }
                    break;
                }
                case 1: {
                    short[] outData2 = new short[this.width];
                    for (int l = 0; l < this.height; ++l) {
                        raster.getDataElements(0, l, this.width, 1, outData2);
                        for (int n2 = 0; n2 < this.width; ++n2) {
                            iArray[n2] = (outData2[n2] & 0xFFFF);
                        }
                        this.theConsumer.setPixels(0, l, this.width, 1, colorModel, iArray, 0, this.width);
                    }
                    break;
                }
                default: {
                    n = true;
                    break;
                }
            }
        }
        if (!(n == 0)) {
            ColorModel rgBdefault = ColorModel.getRGBdefault();
            this.theConsumer.setColorModel(rgBdefault);
            for (int y4 = 0; y4 < this.height; ++y4) {
                for (int x = 0; x < this.width; ++x) {
                    iArray[x] = this.image.getRGB(x, y4);
                }
                this.theConsumer.setPixels(0, y4, this.width, 1, rgBdefault, iArray, 0, this.width);
            }
        }
    }
    
    private void produce() {
        try {
            this.theConsumer.setDimensions(this.image.getWidth(), this.image.getHeight());
            this.theConsumer.setProperties(this.properties);
            this.sendPixels();
            this.theConsumer.imageComplete(2);
            this.theConsumer.imageComplete(3);
        }
        catch (NullPointerException ex) {
            if (this.theConsumer != null) {
                this.theConsumer.imageComplete(1);
            }
        }
    }
}
